% style.m
%
% Produces Figure 5 in:
% Matthias Doepke and Fabrizio Zilibotti, "Parenting with Style: Altruism 
% and Paternalism in Intergenerational Preference Transmission"
% 
% This version: May 8, 2017

close all
clear all

global bet sig abar R lam

bet=0.8;    % Intragenerational discount factor
sig=0.5;    % Coefficient of relative risk aversion

abar=1.5;    % Extent to which the young like early utility

y_H=1.2;    % Income risk
y_L=0.8;

lam=.95;    % Extent of paternalism



grid=1000;  % Grid sizes for computation
grid_a=20;

p_style=zeros(grid,grid);
mu_grid=linspace(1.1,1.25,grid);
R_grid=linspace(0.01,2,grid);
A_grid=linspace(0,abar-1,grid_a);

% Go through R, mu combinations, compute optimal style for each
j=1;
while j<=grid
    
    j 
    
    mu=mu_grid(j);

    h=1;
    while h<=grid
        
        R=R_grid(h);
       

        % Need to compute value of independence or authoritarian parenting
        % Authoritarian can be solved directly
        % Independence involves computing the optimal a for child

        % Utility to parent of keeping the child at home
        % First, optimal investment chosen by parent
        e_bar=(1-((lam+(1-lam)*abar)/(bet*R))^(1/sig))...
            /(1+R*((lam+(1-lam)*abar)/(bet*R))^(1/sig));
        
        % Utility derived from such a child
        U_home=mu^(1-sig)*(y_H^(1-sig)+y_L^(1-sig))*(1/(2*(1-sig)))...
            *((lam+(1-lam)*abar)*(1-e_bar)^(1-sig)+bet*(1+R*e_bar)^(1-sig));


        % Now compute effort chosen by independent child for each a
        i=1;
        while i<= grid_a
            e_a(i)=(1-((abar-A_grid(i))/(bet*R))^(1/sig))...
                /(1+R*((abar-A_grid(i))/(bet*R))^(1/sig));

            i=i+1;

        end

        % Take the max of the resulting utilities
        [U_city a_ind]=max(y_H^(1-sig)*(1/(1-sig))...
            *((lam+(1-lam)*(abar-A_grid)).*(1-e_a).^(1-sig)+bet*(1+R*e_a).^(1-sig)));
        
        % Resulting optimal parenting style for current R, mu combination
        if U_home>=U_city
            p_style(j,h)=1;
        elseif a_ind==1
            p_style(j,h)=2;
        else
            p_style(j,h)=3;
        end
            
            
        h=h+1;
    end
    j=j+1;

end

% Now compute the set boundaries
mu_val=1;
R_val=1;

j=1;
while j<=grid-1
    
    h=1;
    while h<=grid-1
        
        if (p_style(j,h) ~= p_style(j+1,h))|(p_style(j,h) ~= p_style(j,h+1))|(p_style(j,h) ~= p_style(j+1,h+1))
            
            mu_val=[mu_val mu_grid(j)];
            R_val=[R_val R_grid(h)];
            
        end

        h=h+1;
    end
    j=j+1;

end
    
% Remove the first element
mu_val=mu_val(2:length(mu_val));
R_val=R_val(2:length(R_val));

scatter(mu_val,R_val,15,'s','filled');
hold on
axis([1.1 1.25 0 2]);
xlabel('\mu')
ylabel('R')
hold off

